summaryrefslogtreecommitdiffstats
path: root/kmail/identitylistview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/identitylistview.h')
-rw-r--r--kmail/identitylistview.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmail/identitylistview.h b/kmail/identitylistview.h
index 7269237e..6b8e36e2 100644
--- a/kmail/identitylistview.h
+++ b/kmail/identitylistview.h
@@ -42,14 +42,14 @@ namespace KMail {
class IdentityListView;
/** @short A QListViewItem for use in IdentityListView
@author Marc Mutz <mutz@kde.org>
**/
class IdentityListViewItem : public KListViewItem {
public:
IdentityListViewItem( IdentityListView * parent,
const KPIM::Identity & ident );
- IdentityListViewItem( IdentityListView * parent, QListViewItem * after,
+ IdentityListViewItem( IdentityListView * parent, TQListViewItem * after,
const KPIM::Identity & ident );
uint uoid() const { return mUOID; }
@@ -69,15 +69,15 @@ namespace KMail {
class IdentityListView : public KListView {
Q_OBJECT
public:
- IdentityListView( QWidget * parent=0, const char * name=0 );
+ IdentityListView( TQWidget * parent=0, const char * name=0 );
virtual ~IdentityListView() {}
public slots:
- void rename( QListViewItem *, int );
+ void rename( TQListViewItem *, int );
protected:
- bool acceptDrag( QDropEvent * ) const;
- QDragObject * dragObject();
+ bool acceptDrag( TQDropEvent * ) const;
+ TQDragObject * dragObject();
};
@@ -42,14 +42,14 @@ namespace KMail {
class IdentityListView;
- /** @short A QListViewItem for use in IdentityListView
+ /** @short A TQListViewItem for use in IdentityListView
**/